Interface Internationalization

All Known Implementing Classes:
ResourceBundleInternationalization

public interface Internationalization
Provides locale-specific messages.
Since:
1.0.0
  • Method Details

    • getMessage

      String getMessage(Locale locale, String key)
      Retrieves a message.
      Parameters:
      locale - The locale corresponding to the translation to be used
      key - The message key
      Returns:
      The message, otherwise, a String containing the message key surrounded with "%"
      Since:
      1.0.0
    • getMessage

      String getMessage(Locale locale, String key, Object... argumentArray)
      Retrieves a message.
      Parameters:
      locale - The locale corresponding to the translation to be used
      key - The message key
      argumentArray - The message arguments
      Returns:
      The message, otherwise, a String containing the message key surrounded with "%"
      Since:
      1.0.0
    • getMessage

      String getMessage(Locale locale, long quantity, String key, Object... argumentArray)
      Retrieves a message.
      Parameters:
      locale - The locale corresponding to the translation to be used
      quantity - The quantity to determine the plural key to use
      key - The message key
      argumentArray - The message arguments
      Returns:
      The message, otherwise, a String containing the message key surrounded with "%"
      Since:
      1.0.0
    • getAllMessages

      Map<String,String> getAllMessages(Locale locale)
      Retrieves all messages with linked key.
      Parameters:
      locale - The locale
      Returns:
      A Map containing all messages with linked key
      Since:
      1.5.0