Package dev.voidframework.i18n
Interface Internationalization
- All Known Implementing Classes:
ResourceBundleInternationalization
public interface Internationalization
Provides locale-specific messages.
- Since:
- 1.0.0
-
Method Summary
Modifier and TypeMethodDescriptiongetAllMessages(Locale locale) Retrieves all messages with linked key.getMessage(Locale locale, long quantity, String key, Object... argumentArray) Retrieves a message.getMessage(Locale locale, String key) Retrieves a message.getMessage(Locale locale, String key, Object... argumentArray) Retrieves a message.
-
Method Details
-
getMessage
Retrieves a message.- Parameters:
locale- The locale corresponding to the translation to be usedkey- The message key- Returns:
- The message, otherwise, a String containing the message key surrounded with "%"
- Since:
- 1.0.0
-
getMessage
Retrieves a message.- Parameters:
locale- The locale corresponding to the translation to be usedkey- The message keyargumentArray- The message arguments- Returns:
- The message, otherwise, a String containing the message key surrounded with "%"
- Since:
- 1.0.0
-
getMessage
Retrieves a message.- Parameters:
locale- The locale corresponding to the translation to be usedquantity- The quantity to determine the plural key to usekey- The message keyargumentArray- The message arguments- Returns:
- The message, otherwise, a String containing the message key surrounded with "%"
- Since:
- 1.0.0
-
getAllMessages
Retrieves all messages with linked key.- Parameters:
locale- The locale- Returns:
- A
Mapcontaining all messages with linked key - Since:
- 1.5.0
-