Interface Internationalization

All Known Implementing Classes:
ResourceBundleInternationalization

public interface Internationalization
Provides locale-specific messages.
  • Method Details

    • getMessage

      String getMessage(Locale locale, String key)
      Retrieves a message.
      Parameters:
      locale - The locale corresponding to the translation to be used
      key - The message key
      Returns:
      The message, otherwise, a String containing the message key surrounded with "%"
    • getMessage

      String getMessage(Locale locale, String key, Object... argumentArray)
      Retrieves a message.
      Parameters:
      locale - The locale corresponding to the translation to be used
      key - The message key
      argumentArray - The message arguments
      Returns:
      The message, otherwise, a String containing the message key surrounded with "%"
    • getMessage

      String getMessage(Locale locale, long quantity, String key, Object... argumentArray)
      Retrieves a message.
      Parameters:
      locale - The locale corresponding to the translation to be used
      quantity - The quantity to determine the plural key to use
      key - The message key
      argumentArray - The message arguments
      Returns:
      The message, otherwise, a String containing the message key surrounded with "%"